..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

==============
 Invenio-Base
==============

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-base.svg
        :target: https://github.com/inveniosoftware/invenio-base/blob/master/LICENSE

.. image:: https://github.com/inveniosoftware/invenio-base/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-base/actions?query=workflow%3ACI

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-base.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-base

.. image:: https://img.shields.io/pypi/v/invenio-base.svg
        :target: https://pypi.org/pypi/invenio-base


Base package for building Invenio application factories.

Further documentation is available on https://invenio-base.readthedocs.io/
